package com.loganmagnan.eventcore.managers.hotbar;

import lombok.AllArgsConstructor;
import lombok.Getter;
import lombok.RequiredArgsConstructor;
import lombok.Setter;
import org.bukkit.inventory.ItemStack;

import java.util.Objects;

@Getter
@Setter
@AllArgsConstructor
@RequiredArgsConstructor
public class ClickableItem {

    private ClickHandler clickHandler;

    private ItemStack itemStack;

    private boolean moveable = false;
    private boolean placeable = false;
    private boolean droppable = false;

    @Override
    public boolean equals(Object object) {
        if (object == this) {
            return true;
        }

        if (!(object instanceof ClickableItem)) {
            return false;
        }

        ClickableItem clickableItem = (ClickableItem) object;

        if (!clickableItem.canEqual(this)) {
            return false;
        }

        Object thisClickHandler = this.clickHandler;
        Object otherClickHandler = clickableItem.getClickHandler();

        if (!Objects.equals(thisClickHandler, otherClickHandler)) {
            return false;
        }

        Object thisItemStack = getItemStack();
        Object otherItemStack = clickableItem.getItemStack();

        return (Objects.equals(thisItemStack, otherItemStack)) && (this.droppable == clickableItem.isDroppable() && (this.moveable == clickableItem.isMoveable() && (this.placeable == clickableItem.isPlaceable())));
    }

    @Override
    public int hashCode() {
        int result = 1;

        Object clickHandler = this.clickHandler;

        result = result * 59 + ((clickHandler == null) ? 43 : clickHandler.hashCode());

        Object itemStack = this.itemStack;

        result = result * 59 + ((itemStack == null) ? 43 : itemStack.hashCode());
        result = result * 59 + (this.droppable ? 79 : 97);
        result = result * 59 + (this.moveable ? 79 : 97);

        return result * 59 + (this.placeable ? 79 : 97);
    }

    protected boolean canEqual(Object object) {
        return object instanceof ClickableItem;
    }

    @Override
    public String toString() {
        return "ClickableItem(clickHandler=" + this.clickHandler + ", itemStack=" + this.itemStack + ", droppable=" + this.droppable + ", moveable=" + this.moveable + ", placeable=" + this.placeable + ")";
    }
}
